@@ -47,22 +47,21 @@
 #define CC 0x98badcfe
 #define DD 0x10325476
 
-static void (*md5_50_variant)();
-static void md5_50f(uint8_t *msg, const unsigned int msgLen);
-static void md5_50s(uint8_t *msg, const unsigned int msgLen);
+static void (*md5_50_variant)(uint8_t *msg, size_t msgLen);
+static void md5_50f(uint8_t *msg, size_t msgLen);
+static void md5_50s(uint8_t *msg, size_t msgLen);
 
 void 
-md5(const uint8_t *msg, const unsigned int msgLen, uint8_t *digest) {
+md5(const uint8_t *msg, size_t msgLen, uint8_t *digest) {
   uint32_t x[16];
   register uint32_t a, b, c, d;
   uint32_t aa, bb, cc, dd;
-  int n64;
-  int i, j;
-  unsigned int k;
+  size_t n64, i, k;
+  int j;
   
   /** compute number of 64-byte blocks
       (length + pad byte (0x80) + 8 bytes for length) */
-  n64 = ((int)msgLen + 72) / 64;
+  n64 = (msgLen + 72) / 64;
   
   /** initialize a, b, c, d */
   a = AA;
@@ -75,7 +74,7 @@ md5(const uint8_t *msg, const unsigned int msgLen, uint8_t *digest) {
   for (i = 0; i < n64; ++i) {
 
     /** grab a 64-byte block */
-    for (j = 0; j < 16 && (signed)k < (signed)msgLen - 3; ++j, k += 4)
+    for (j = 0; j < 16 && k < msgLen - 3; ++j, k += 4)
       x[j] = ((((((unsigned)msg[k+3] << 8) + (unsigned)msg[k+2]) << 8) + (unsigned)msg[k+1]) << 8) + msg[k];
     if (i == n64 - 1) {
       if (k == msgLen - 3)
@@ -197,14 +196,14 @@ md5(const uint8_t *msg, const unsigned int msgLen, uint8_t *digest) {
 }
 
 static void
-md5_50s(uint8_t *msg, const unsigned int msgLen) {
+md5_50s(uint8_t *msg, size_t msgLen) {
   int i;
   for(i=0; i<50; i++) { md5(msg, msgLen, msg); }
 }
 
 /** fast version of "for(i=0; i<50; i++) { md5(msg, 16, msg); }" */
 static void 
-md5_50f(uint8_t *msg, const unsigned int msgLen __attribute__((unused))) {
+md5_50f(uint8_t *msg, size_t msgLen __attribute__((unused))) {
   register uint32_t a, b, c, d;
   int i;
 
@@ -322,7 +321,7 @@ md5_50f(uint8_t *msg, const unsigned int msgLen __attribute__((unused))) {
 }
 
 void
-md5_50_init(const unsigned int msgLen) {
+md5_50_init(size_t msgLen) {
   if(msgLen == 16)
     md5_50_variant = &md5_50f;
   else
@@ -330,6 +329,6 @@ md5_50_init(const unsigned int msgLen) {
 }
 
 void
-md5_50(uint8_t *msg, const unsigned int msgLen) {
+md5_50(uint8_t *msg, size_t msgLen) {
   md5_50_variant(msg, msgLen);
 }
