@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2020 Henning Norén
+ * Copyright (C) 2006-2022 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -93,7 +93,7 @@ parseInt(FILE *file) {
 }
 
 
-static char
+static int
 parseWhiteSpace(FILE *file) {
   int ch;
   do {
@@ -140,7 +140,7 @@ parseName(FILE *file) {
   }
   ungetc(ch, file);
   buff[i++] = '\0';
-  ret = malloc(sizeof(char)*i);
+  ret = checked_malloc(sizeof(char)*i);
   memcpy(ret, buff, i);
   return ret;
 }
@@ -216,8 +216,8 @@ parseHexString(const uint8_t *buf, const unsigned int len) {
   unsigned int i,j;
   p_str *ret;
 
-  ret = malloc(sizeof(p_str));
-  ret->content = malloc(sizeof(uint8_t)*(len/2));
+  ret = checked_malloc(sizeof(p_str));
+  ret->content = checked_malloc(sizeof(uint8_t)*(len/2));
   ret->len = (len/2);
 
   for(i=0, j=0; i<len; i += 2) {
@@ -293,8 +293,8 @@ objStringToByte(const uint8_t* str, const unsigned int len) {
     tmp[l] = b;
   }
 
-  ret = malloc(sizeof(p_str));
-  ret->content = malloc(sizeof(uint8_t)*(l));
+  ret = checked_malloc(sizeof(p_str));
+  ret->content = checked_malloc(sizeof(uint8_t)*(l));
   ret->len = l-1;
 
   memcpy(ret->content, tmp, l);
